==================
Welcome to |Cov_s|
==================

.. include:: ../README.rst
   :start-line: 4

======================
Full package reference
======================

.. toctree::

   parameters
   whatsnew
   contributing
   webapp
   docker
   data
   modules



